import React from 'react';
import PropTypes from 'prop-types';
import Fade from 'react-bootstrap/es/Fade';

import LoginCardInputWarning from './LoginCardInputWarning';
import { FormControl, FormGroup, HelpBlock } from '../../../../index';
import { noop } from '../../../../common/helpers';

var LoginCardInput = function LoginCardInput(_ref) {
  var id = _ref.id,
      type = _ref.type,
      placeholder = _ref.placeholder,
      size = _ref.size,
      error = _ref.error,
      warning = _ref.warning,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      onKeyPress = _ref.onKeyPress,
      showError = _ref.showError,
      showWarning = _ref.showWarning,
      className = _ref.className,
      autoComplete = _ref.autoComplete;

  var helpBlock = showError && React.createElement(
    HelpBlock,
    null,
    error
  ) || showWarning && React.createElement(
    LoginCardInputWarning,
    null,
    warning
  );

  return React.createElement(
    FormGroup,
    { className: 'login_card_input ' + className, controlId: id, validationState: showError ? 'error' : null },
    React.createElement(FormControl, {
      type: type,
      placeholder: placeholder,
      bsSize: size,
      onChange: onChange,
      onFocus: onFocus,
      onBlur: onBlur,
      onKeyPress: onKeyPress,
      autoComplete: autoComplete
    }),
    React.createElement(
      Fade,
      { 'in': showError || showWarning },
      React.createElement(
        'div',
        null,
        helpBlock
      )
    )
  );
};

LoginCardInput.propTypes = {
  id: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  type: PropTypes.string,
  placeholder: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  size: PropTypes.string,
  error: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  warning: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  onChange: PropTypes.func,
  showWarning: PropTypes.bool,
  onBlur: PropTypes.func,
  onFocus: PropTypes.func,
  onKeyPress: PropTypes.func,
  showError: PropTypes.bool,
  className: PropTypes.string,
  autoComplete: PropTypes.string
};

LoginCardInput.defaultProps = {
  id: Math.random().toString(),
  type: 'text',
  placeholder: 'Enter Text',
  size: 'lg',
  error: null,
  warning: null,
  onChange: noop,
  showWarning: false,
  onBlur: noop,
  onFocus: noop,
  onKeyPress: noop,
  showError: false,
  className: '',
  autoComplete: ''
};

export default LoginCardInput;